use std::collections::HashMap;
use std::io::{stdout, Write};
use std::{env, thread};
use zbus::blocking::Connection;
use zbus::{proxy, zvariant, Result};

#[proxy(
    interface = "org.freedesktop.Notifications",
    default_service = "org.freedesktop.Notifications",
    default_path = "/org/freedesktop/Notifications"
)]
trait MyGreeter {
    fn notify(
        &self,
        app_name: &str,
        replace_id: u32,
        app_icon: &str,
        summary: &str,
        body: &str,
        actions: &[&str],
        hints: HashMap<&str, zvariant::Value<'_>>,
        expire_timeout: i32,
    ) -> Result<u32>;
}

fn send_dbus_timer_out() {
    let connection = Connection::session().unwrap();
    let proxy = MyGreeterProxyBlocking::new(&connection).unwrap();
    let result = proxy
        .notify("", 0, "", "🍎", "Timer fini", &["a"], HashMap::new(), 0)
        .unwrap();
    dbg!(result);
}

fn main() {
    // FIXME: use clap and "start {}" instead of the second arg
    let total_duration: u32 = env::args().nth(2).unwrap().parse::<u32>().unwrap() * 60;

    for n in 0..(total_duration) {
        let left = total_duration - n;
        print!("\r{:02}:{:02} left", left / 60, left % 60);
        stdout().flush().unwrap();
        thread::sleep(std::time::Duration::from_secs(1));
    }

    send_dbus_timer_out();
}
